@@ -115,19 +115,26 @@ class Key:
         return self.workdir / 'scene' / self.filename
 
 
+class Texture(Key):
+    @property
+    def dst(self):
+        return self.workdir / 'maps'
+
+
 class Render:
     def __init__(self, scene: Key, client: S3, texture: str = None):
         self.scene = scene
         self.client = client
-        self.texture = texture and Key(texture)
+        self.texture = texture and Texture(texture)
 
     def unpack_texture(self):
         if self.texture:
             self.client.download_file(self.texture.path, self.texture.localfile)
             logger.info(f"Texture downloaded - {self.texture.localfile}")
+            self.texture.dst.mkdir(exist_ok=True)
             with zipfile.ZipFile(self.texture.localfile, 'r') as f:
-                f.extractall(self.texture.workdir)
-            logger.info(f"Texture unzipped to - {self.texture.workdir}")
+                f.extractall(self.texture.dst)
+            logger.info(f"Texture unzipped to - {self.texture.dst}")
 
     def run(self, extension='exr'):
         self.unpack_texture()
@@ -144,7 +151,7 @@ class Render:
             f'-outputName:{str(self.scene.workdir / f"0.{extension}")}',
         ]
         if self.texture:
-            args.append(f'-bitmapPath:{self.texture.localfile}')
+            args.append(f'-bitmapPath:{self.texture.dst}')
         args.append(str(self.scene.localfile))
         logger.debug(f"Params = {args}")
 
